#!/bin/bash
set -e

function prepend-with-date {
  while read line
  do
    echo $(date +%Y-%m-%dT%H:%M:%S%z) $line
  done
}

{% set cluster_data = jsonMap(container.clusterData()) %}
{% set instance_data = jsonMap(container.instanceData()) %}
{% set majorVersion = container.parsedVersion().major() %}
{% set minorVersion = container.parsedVersion().minor() %}
{% set patchVersion = container.parsedVersion().patch() %}

if [[ $(id -u) -eq 0 ]]; then
    echo "ERROR: apm.sh running as uid 0 (root), exiting."
    exit 1
fi

cd /app

mkdir -p logs
BOOT_LOG_FILE=logs/boot.log
# save stdout and stderr for later
exec 3>&1 4>&2
exec >  >(prepend-with-date | tee -a $BOOT_LOG_FILE)
exec 2> >(prepend-with-date | tee -a $BOOT_LOG_FILE >&2)

echo "Booting at $(date)"

echo "Done preparing, starting Apm. See Apm logs for further output."

# used by metricbeat
export ECE_COMPONENT="apm"
export ECE_CLUSTER_NAME="{{ container.id().group() }}"
export ECE_INSTANCE_ID="{{ container.id().name() }}"
export ECE_CLUSTER_VERSION="{{ container.versionString() }}"

# restore stdout and stderr
exec 1>&3 2>&4

{% if instance_data.apm.debug_enabled|default(false) %}
# we do not use -e option as we want the things to be logged to apm.log and not to standard error (as we do not log that)
  {% set debug_enabled_flag = '-d "*" ' %}
{% else %}
  {% set debug_enabled_flag = "" %}
{% endif %}

HOME_PATH=/app
CONFIG_PATH=/app/config
DATA_PATH=/app/data
LOGS_PATH=/app/logs

{% if majorVersion == 6 and minorVersion <= 6 %}
cp /usr/share/apm-server/fields.yml ${CONFIG_PATH}/
cp -Rf /usr/share/apm-server/kibana ${HOME_PATH}/ || true
{% set basePath = "/usr/share/apm-server" %}
{% else %}
{% set basePath = "/apm-server" %}
{% endif %}
cp -Rf {{ basePath }}/ingest ${HOME_PATH}/ || true

{{ basePath }}/apm-server {{ debug_enabled_flag }}-c /app/config/apm-server.yml --httpprof :{{ container.monitoringPort() }} --path.home=${HOME_PATH} --path.config=${CONFIG_PATH} --path.data=${DATA_PATH} --path.logs=${LOGS_PATH} $*

APM_EXIT_CODE=$?
exit $APM_EXIT_CODE
